/*******************************************************************************
* File Name: main.c
*
* PSoC Creator Version: 2.1
*
* Description:
*  This project demonstrates the interfacing of PIR sensor using PSoC 3. The device is 
*  put to sleep and wakes up from sleep every 256ms , scan the PIR sensor and go 
*  back to sleep. Character 'x' is displayed on the LCD if PIR sensor is active.
*
********************************************************************************/

#include <device.h>

#define TRUE 0xFF

#define FALSE 0
 
#define THRESHOLD_COUNT 20
 
#define BASE_LINE_UPDATE_TIME 5
 
uint8 adc_done_flag = FALSE;
int16 adc_data, sensor_baseline ,diff_count;


void Device_Sleep(void)
{
	/* Components shut down */
	ADC_DelSig_1_Sleep();

	/* Save the clocks and put the device to sleep */
	CyPmSaveClocks();
	CyPmSleep( PM_SLEEP_TIME_CTW_256MS,PM_SLEEP_SRC_CTW);
   
	/*Read the sleep timer status */
	CY_GET_REG8(CYREG_PM_INT_SR);
	
	/* Restore the clocks */
	CyPmRestoreClocks();
	
	/* Wake up the components */
	ADC_DelSig_1_Wakeup();

}

void main()
{
    /* Place your initialization/startup code here (e.g. MyInst_Start()) */
	
	uint8 sensor_active_count = 0;
	
    CyGlobalIntEnable; /* Uncomment this line to enable global interrupts. */
	
	/* Start the LCD */
	LCD_Char_1_Start();

	/* Enable the ADC */
	ADC_DelSig_1_Start();
	
	/* You are going for a polling method to for ADC result.
	 * Therefore disable the ADC interrupts */
	ADC_DelSig_1_IRQ_Disable();
	
	/* ADC is in single sample mode , So need to start the convertion */
	ADC_DelSig_1_StartConvert();
	
	/* Wait for the first ADC sample to initialize */
	ADC_DelSig_1_IsEndConversion(ADC_DelSig_1_WAIT_FOR_RESULT);
	
	adc_data = ADC_DelSig_1_GetResult16();
	
	/* sensor_baseline is used as the threshold to detect movements */
	sensor_baseline = adc_data;

	ADC_DelSig_1_StartConvert();
	
	/* Start the sleep timer and its associated ISR */
	isr_WakeUp_Start();					/* Sleep timer interrupt */
	isr_WakeUp_ClearPending();
	
	SleepTimer_1_Start();
	SleepTimer_1_EnableInt();
	
    for(;;)
    {

		/* Wait for ADC result and then read the adc output */
		ADC_DelSig_1_IsEndConversion(ADC_DelSig_1_WAIT_FOR_RESULT);
		adc_data = ADC_DelSig_1_GetResult16();

	  	/* Find the difference between the current sample and sensor_baseline(previous adc sample) */	
		if(adc_data > sensor_baseline)
		{
		    diff_count = adc_data - sensor_baseline;
		}
		else
		{
			diff_count = sensor_baseline - adc_data;
		}
		
		/* If the difference count is greated than the threshold 
		 * it is detected as sensor active and display 'X' in the LCD 
		 * Remove the LCD part if you want to minimize the current (reduces the wakeup time during sleep mode)*/
	    if(diff_count > THRESHOLD_COUNT)
	    {
			
			/* Pin_LED_Write(1);  */
			LCD_Char_1_Position(0,0);
			LCD_Char_1_PrintString("X");
			
			/* Increment the sensor active count */
			sensor_active_count++;
			
			/* If the diff count is greater that the threshold for more than 256ms * 5(BASE_LINE_UPDATE_TIME),
			 * then update the sensor baseline itself to the new value */
			if(sensor_active_count > BASE_LINE_UPDATE_TIME)
			{
				sensor_baseline = adc_data;
			}
	    }
		/* If the sensor is not active , clear the display
		 * Set the baseline as the current adc_data */
	    else
	    {
			sensor_active_count = 0;
			/*Pin_LED_Write(1);  */
			LCD_Char_1_Position(0,0);
			LCD_Char_1_PrintString(" ");
			sensor_baseline = adc_data;

		}

		Device_Sleep();
		/*CyDelay(100); */ /* Uncomment this if, you are not using sleep and wakeup  */

		ADC_DelSig_1_Start();
		ADC_DelSig_1_StartConvert();
		
		/* Uncomment the following code to display the adc results on the LCD */
		/*
		LCD_Char_1_Position(0,0);
		LCD_Char_1_PrintString("                        ");
		LCD_Char_1_Position(1,0);
		LCD_Char_1_PrintString("                        ");
		
		LCD_Char_1_Position(0,0);
		LCD_Char_1_PrintNumber(adc_data);

		LCD_Char_1_Position(1,0);
		LCD_Char_1_PrintNumber(diff_count);
		*/
		/* Place your application code here. */

	}
	
}


/* [] END OF FILE */
